import { AUTH_ACTION_TYPES } from "./types";

interface IActionBase<T> {
    type: T
}

export interface IResponse<T, R> {
    type: T,
    response: R,
}

export interface IError<T, E>{
    type: T,
    error: E,
}
  

export interface ISignUpAction {
    email: string;
    password: string;
    firstName: string;
    lastName: string
}  
  
export interface ISignUp extends IActionBase<AUTH_ACTION_TYPES.SIGN_UP>, ISignUpAction {}

export interface IConfirmSignUp extends IActionBase<AUTH_ACTION_TYPES.CONFIRM_SIGN_UP> {
    confirmationCode: string;
}
  
export interface IResendConfirmationCode extends IActionBase<AUTH_ACTION_TYPES.RESEND_CONFIRMATION_CODE> {
    email: string;
}

export interface ISignUpSuccessful extends IActionBase<AUTH_ACTION_TYPES.SIGN_UP_SUCCESSFUL> {
    response: any; 
}

export interface ISignInAction {
    email: string;
    password: string;
}

export interface ISignInSuccessful extends IActionBase<AUTH_ACTION_TYPES.SIGN_IN_SUCCESSFUL> {
    response: any; 
}

export interface ISignIn extends IActionBase<AUTH_ACTION_TYPES.SIGN_IN>, ISignInAction {}

export interface ISignOut extends IActionBase<AUTH_ACTION_TYPES.SIGN_OUT> {}

export interface IForgotPassword extends IActionBase<AUTH_ACTION_TYPES.FORGOT_PASSWORD> {
    email: string;
}

export interface IForgotPasswordSubmit extends IActionBase<AUTH_ACTION_TYPES.FORGOT_PASSWORD_SUBMIT> {
    code: string;
    newPassword: string;
}

export interface IChangePassword extends IActionBase<AUTH_ACTION_TYPES.CHANGE_PASSWORD> {
    oldPassword: string;
    newPassword: string;
}

export interface IChangeAttributes extends IActionBase<AUTH_ACTION_TYPES.CHANGE_ATTRIBUTES>{
    name: string;
    email: string;
}
